class Config(object):

    JOOX_API_DOMAIN = "https://api-jooxtt.sanook.com/web-fcgi-bin"
    JOOX_AUTH_PATH = "/web_wmauth"
    JOOX_GETFAV_PATH = "/web_getfav"
    JOOX_ADD_DIR_PATH = "/web_fav_add_dir"
    JOOX_DEL_DIR_PATH = "/web_fav_del_dir"
    JOOX_ADD_SONG_PATH = "/web_fav_add_song"
    JOOX_DEL_SONG_PATH = "/web_fav_del_song"
    JOOX_SEARCH_PATH = "/web_search"
    JOOX_TAG_LIST_PATH = "/web_tag_list"
    JOOX_RECOMMENDED_MORE_PATH = "/web_recommend_more"
    JOOX_GET_DISS_PATH = "/web_get_diss"
    JOOX_GET_ALBUMINFO_PATH = "/web_get_albuminfo"
    JOOX_HOT_QUERY_PATH = "/web_hot_query"
    JOOX_GET_TOPLIST_PATH = "/web_get_toplist"
    JOOX_TOPLIST_DETAIL_PATH = "/web_toplist_detail"
    JOOX_ALL_SINGER_LIST_PATH = "/web_all_singer_list"
    JOOX_SINGER_CATEGORY_PATH = "/web_singer_category"
    JOOX_ALBUM_SINGER_PATH = "/web_album_singer"
    JOOX_LYRIC_PATH = "/web_lyric"
    JOOX_GET_SONGINFO_PATH = "/web_get_songinfo"
