__copyright__ = "Copyright 2019 by Ervan R.F"
__version__ = "1.0.4"
__license__ = "BSD-3-Clause"
__author__ = "Ervan R.F"
__author_email__ = "ervanroot@gmail.com"
__url__ = "http://github.com/ervan0707/jooxy"

from .auth import Jooxy
from .config import Config
from .client import Client
from .user import User
from .sessions import Sessions